%define anolis_release 1

%bcond_without      docs
%bcond_without      tests
%bcond_with         linkcheck
%bcond_without      asciidoctor
%bcond_with         cvs
%bcond_without      libsecret
%bcond_without      p4

%bcond_without      use_glibc_langpacks
%bcond_without      use_perl_generators
%bcond_without      use_perl_interpreter

%global bashcompdir         %(pkg-config --variable=completionsdir bash-completion 2>/dev/null)
%global bashcomproot        %(dirname %{bashcompdir} 2>/dev/null)
%global _package_note_file  %{_builddir}/%{name}-%{version}/.package_note-%{name}-%{version}-%{release}.%{_arch}.ld

Name:           git
Version:        2.40.1
Release:        %{anolis_release}%{?dist}
Summary:        Distributed version control system
License:        GPLv2
URL:            https://git-scm.com/
Source0:        https://www.kernel.org/pub/software/scm/git/%{name}-%{version}.tar.xz
Source1:        git.xinetd.in
Source2:        git-gui.desktop
Source3:        gitweb-httpd.conf
Source4:        gitweb.conf.in
Source5:        git@.service.in
Source6:        git.socket
Source7:        print-failed-test-output

Patch0:         git-cvsimport-Ignore-cvsps-2.2b1-Branches-output.patch
Patch1:         0001-t-lib-httpd-try-harder-to-find-a-port-for-apache.patch
Patch2:         0002-t-lib-git-daemon-try-harder-to-find-a-port.patch
Patch3:         0003-t-lib-git-svn-try-harder-to-find-a-port.patch

%if %{with docs}
BuildRequires:  %{_bindir}/pod2man
%if %{with asciidoctor}
BuildRequires:  docbook5-style-xsl rubygem-asciidoctor
%else
BuildRequires:  asciidoc >= 8.4.1
%endif
BuildRequires:  perl(File::Compare) xmlto
%if %{with linkcheck}
BuildRequires:  linkchecker
%endif
%endif
BuildRequires:  coreutils desktop-file-utils diffutils expat-devel
BuildRequires:  findutils gawk gettext sed
BuildRequires:  gcc gcc-c++ make autoconf
BuildRequires:  openssl openssl-devel libcurl-devel pcre2-devel
BuildRequires:  perl(lib) perl(Error) perl(Test)
%if %{with use_perl_generators}
BuildRequires:  perl-generators
%endif
%if %{with use_perl_interpreter}
BuildRequires:  perl-interpreter
%else
BuildRequires:  perl
%endif
BuildRequires:  pkgconfig(bash-completion)
BuildRequires:  systemd tcl tk xz zlib-devel >= 1.2

%if %{with tests}
BuildRequires:  bash acl mod_http2 
%if %{with cvs}
BuildRequires:  cvs cvsps
%endif
%if %{with use_glibc_langpacks}
BuildRequires:  glibc-all-langpacks glibc-langpack-en glibc-langpack-is
%endif
BuildRequires:  gnupg2-smime
%if "%{_arch}" == "x86_64"
BuildRequires:  highlight
%endif
BuildRequires:  httpd mod_ssl mod_dav_svn openssh-clients
BuildRequires:  perl(App::Prove)
BuildRequires:  perl(CGI) perl(CGI::Carp) perl(CGI::Util)
BuildRequires:  perl(DBD::SQLite) perl(Digest::MD5)
BuildRequires:  perl(Fcntl) perl(File::Basename) perl(File::Copy) perl(File::Find) perl(filetest)
BuildRequires:  perl(HTTP::Date) perl(IO::Pty)
BuildRequires:  perl(JSON) perl(JSON::PP)
BuildRequires:  perl(Mail::Address)
BuildRequires:  perl(Memoize) perl(POSIX)
BuildRequires:  perl(Term::ReadLine) perl(Test::More) perl(Time::HiRes)
BuildRequires:  python3-devel
BuildRequires:  subversion subversion-perl
BuildRequires:  tar time zip
%endif


Requires:       git-core = %{version}-%{release} git-core-doc = %{version}-%{release}  
%if ! %{defined perl_bootstrap}
Requires:       perl(Term::ReadKey)
%endif
Requires:       perl-Git = %{version}-%{release}
%if %{without cvs}
Obsoletes:      git-cvs < %{?epoch:%{epoch}:}%{version}-%{release}
%endif
%if %{without p4}
Obsoletes:      git-p4 < %{?epoch:%{epoch}:}%{version}-%{release}
%endif

%description
Git is a free and open source distributed version control system designed 
to handle everything from small to very large projects with speed and efficiency.

Git is easy to learn and has a tiny footprint with lightning fast performance. 
It outclasses SCM tools like Subversion, CVS, Perforce, and ClearCase with features 
like cheap local branching, convenient staging areas, and multiple workflows.

%package all
Summary:        Meta-package to pull in all git tools
Requires:       git = %{version}-%{release}
Requires:       git-daemon = %{version}-%{release}
Requires:       git-email = %{version}-%{release}
Requires:       git-gui = %{version}-%{release}
Requires:       git-subtree = %{version}-%{release}
Requires:       git-svn = %{version}-%{release}
Requires:       git-instaweb = %{version}-%{release}
Requires:       gitk = %{version}-%{release}
Requires:       perl-Git = %{version}-%{release}
%if %{with libsecret}
Requires:       git-credential-libsecret = %{version}-%{release}
%endif
%if %{with cvs}
Requires:       git-cvs = %{version}-%{release}
%endif
%if %{with p4}
Requires:       git-p4 = %{version}-%{release}
%endif
%if ! %{defined perl_bootstrap}
Requires:       perl(Term::ReadKey)
%endif
BuildArch:      noarch

%description all
This is a dummy package which brings in all subpackages.

%package core
Summary:        Core package of git with minimal functionality
Requires:       less openssh-clients zlib >= 1.2

%description core
The git-core rpm installs really the core tools with minimal
dependencies. Install git package for common set of tools.
To install all git packages, including tools for integrating with
other SCMs, install the git-all meta-package.

%package core-doc
Summary:        Documentation files for git-core
Requires:       git-core = %{version}-%{release}
BuildArch:      noarch

%description core-doc
Documentation files for git-core package including man pages.

%if %{with libsecret}
%package credential-libsecret
Summary:        Git helper for accessing credentials via libsecret
BuildRequires:  libsecret-devel
Requires:       git = %{version}-%{release}
%description credential-libsecret
Git helper for accessing credentials via libsecret.
%endif

%if %{with cvs}
%package cvs
Summary:        Git tools for importing CVS repositories
BuildArch:      noarch
Requires:       git = %{version}-%{release}
Requires:       cvs cvsps perl(DBD::SQLite)   

%description cvs
Git tools for importing CVS repositories
%endif

%package daemon
Summary:            Git protocol daemon
Requires:           git-core = %{version}-%{release}
Requires:           systemd
Requires(post):     systemd
Requires(preun):    systemd
Requires(postun):   systemd

%description daemon
The git daemon for supporting git:// access to git repositories

%package email
Summary:        Git tools for sending patches via email
BuildArch:      noarch
Requires:       git = %{version}-%{release}
Requires:       perl(Authen::SASL) perl(Cwd) perl(Email::Valid)
Requires:       perl(File::Spec) perl(File::Spec::Functions) perl(File::Temp)
Requires:       perl(IO::Socket::SSL) perl(Mail::Address)   
Requires:       perl(MIME::Base64) perl(MIME::QuotedPrint)    
Requires:       perl(Net::Domain) perl(Net::SMTP) perl(Net::SMTP::SSL)
Requires:       perl(POSIX) perl(Sys::Hostname)
Requires:       perl(Term::ANSIColor) perl(Term::ReadLine) perl(Text::ParseWords)    
%description email
Git tools for sending patches via email.

%package -n gitk
Summary:        Git repository browser
BuildArch:      noarch
Requires:       git = %{version}-%{release}
Requires:       git-gui = %{version}-%{release}
Requires:       tk >= 8.4

%description -n gitk
Git repository browser.

%package -n gitweb
Summary:        Simple web interface to git repositories
Requires:       git = %{version}-%{release}
BuildArch:      noarch

%description -n gitweb
Simple web interface to git repositories.

%package gui
Summary:        Graphical interface to Git
Requires:       gitk = %{version}-%{release}
Requires:       tk >= 8.4
BuildArch:      noarch

%description gui
Graphical interface to Git.

%package instaweb
Summary:        Repository browser in gitweb
Requires:       git = %{version}-%{release}
Requires:       gitweb = %{version}-%{release}
Requires:       httpd
BuildArch:      noarch

%description instaweb
A simple script to set up gitweb and a web server for browsing the local repository.

%if %{with p4}
%package p4
Summary:        Git tools for working with Perforce depots
BuildRequires:  python3-devel
Requires:       git = %{version}-%{release}
BuildArch:      noarch

%description p4
Git tools for working with Perforce depots.
%endif

%package -n perl-Git
Summary:        Perl interface to Git
Requires:       git = %{version}-%{release}
BuildArch:      noarch

%description -n perl-Git
Perl interface to Git.

%package -n perl-Git-SVN
Summary:        Perl interface to Git::SVN
Requires:       git = %{version}-%{release}
BuildArch:      noarch

%description -n perl-Git-SVN
Perl interface to Git::SVN.

%package subtree
Summary:        Git tools to merge and split repositories
Requires:       git-core = %{version}-%{release}
BuildArch:      noarch

%description subtree
Git subtrees allow subprojects to be included within a subdirectory of 
the main project, optionally including the subproject's entire history.

%package svn
Summary:        Git tools for interacting with Subversion repositories
Requires:       git = %{version}-%{release} 
Requires:       perl(Digest::MD5) subversion     
%if ! %{defined perl_bootstrap}
Requires:       perl(Term::ReadKey)
%endif
BuildArch:      noarch

%description svn
Git tools for interacting with Subversion repositories.

%prep
%autosetup -n %{name}-%{version} -p1

install -m 0755 -p %{SOURCE7} print-failed-test-output
sed -i '/^SCRIPT_PERL += git-archimport\.perl$/d' Makefile
sed -i '/^git-archimport/d' command-list.txt
rm git-archimport.perl Documentation/git-archimport.txt

%if %{without cvs}
sed -i '/^git-cvs/d' command-list.txt
%endif

%if %{without p4}
sed -i '/^git-p4/d' command-list.txt
%endif

# parameters of make
cat << \EOF | tee config.mak
V = 1
CFLAGS = %{build_cflags}
LDFLAGS = %{build_ldflags}

USE_LIBPCRE = 1
INSTALL_SYMLINKS = 1
GNU_ROFF = 1
NO_PERL_CPAN_FALLBACKS = 1

ETC_GITCONFIG = %{_sysconfdir}/gitconfig
GITWEB_PROJECTROOT = %{_localstatedir}/lib/git
PYTHON_PATH = %{__python3}

htmldir = %{?_pkgdocdir}%{!?_pkgdocdir:%{_docdir}/%{name}-%{version}}
prefix = %{_prefix}
perllibdir = %{perl_vendorlib}
gitwebdir = %{_localstatedir}/www/git

%if %{with asciidoctor}
USE_ASCIIDOCTOR = 1
%endif

DEFAULT_TEST_TARGET = prove
GIT_PROVE_OPTS = --verbose --normalize %{?_smp_mflags} --formatter=TAP::Formatter::File
GIT_TEST_OPTS = -x --verbose-log
EOF

%{?perl_default_filter}
%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}perl\\(packed-refs\\)
%if ! %{defined perl_bootstrap}
%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}perl\\(Term::ReadKey\\)
%endif

rm -rf perl/Git/LoadCPAN{.pm,/}
grep -rlZ '^use Git::LoadCPAN::' | xargs -r0 sed -i 's/Git::LoadCPAN:://g'

sed -i 's@"++GITWEB_HOME_LINK_STR++"@$ENV{"SERVER_NAME"} ? "git://" . $ENV{"SERVER_NAME"} : "projects"@' \
    gitweb/gitweb.perl

mv contrib/{contacts,subtree}/git-*.txt Documentation/

%build
export TZ=UTC
export SOURCE_DATE_EPOCH=$(date -r version +%%s 2>/dev/null)

%make_build all %{?with_docs:doc}
%make_build -C contrib/contacts/ all

%if %{with libsecret}
%make_build -C contrib/credential/libsecret/
%endif

%make_build -C contrib/credential/netrc/
%make_build -C contrib/diff-highlight/
%make_build -C contrib/subtree/ all

rm -rf contrib/fast-import/import-zips.py

sed -i -e '1s@#!\( */usr/bin/env python\|%{__python2}\)$@#!%{__python3}@' \
    contrib/hg-to-git/hg-to-git.py

%install

%make_install %{?with_docs:install-doc}
%make_install -C contrib/contacts

%if %{with libsecret}
install -m 0755 -p contrib/credential/libsecret/git-credential-libsecret %{buildroot}%{_libexecdir}/git-core
%endif
install -m 0755 -p contrib/credential/netrc/git-credential-netrc %{buildroot}%{_libexecdir}/git-core

mv contrib/credential/netrc .

%make_install -C contrib/subtree

mkdir -p %{buildroot}%{_sysconfdir}/httpd/conf.d
install -m 0644 -p %{SOURCE3} %{buildroot}%{_sysconfdir}/httpd/conf.d/gitweb.conf
sed "s|@PROJECTROOT@|%{_localstatedir}/lib/git|g" \
    %{SOURCE4} > %{buildroot}%{_sysconfdir}/gitweb.conf

install -D -m 0755 -p contrib/diff-highlight/diff-highlight %{buildroot}%{_datadir}/git-core/contrib/diff-highlight
rm -rf contrib/diff-highlight/{Makefile,diff-highlight,*.perl,t}

rm -rf contrib/scalar
rm -rf contrib/subtree/{INSTALL,Makefile,git-subtree*,t}

# Remove git-cvs* and gitcvs*
%if %{without cvs}
find %{buildroot} Documentation \( -type f -o -type l \) \
    \( -name 'git-cvs*' -o -name 'gitcvs*' \) -exec rm -f {} ';'
%endif

# Remove git-p4* and mergetools/p4merge
%if %{without p4}
find %{buildroot} Documentation -type f -name 'git-p4*' -exec rm -f {} ';'
rm -f %{buildroot}%{_libexecdir}/git-core/mergetools/p4merge
%endif

# Remove unneeded git-remote-testsvn so git-svn can be noarch
rm -f %{buildroot}%{_libexecdir}/git-core/git-remote-testsvn

exclude_re="email|git-(citool|credential-libsecret|cvs|daemon|gui|instaweb|p4|subtree|svn)|gitk|gitweb|p4merge"
(find %{buildroot}{%{_bindir},%{_libexecdir}} -type f -o -type l | grep -vE "$exclude_re" | sed -e s@^%{buildroot}@@) > bin-man-doc-files
(find %{buildroot}{%{_bindir},%{_libexecdir}} -mindepth 1 -type d | grep -vE "$exclude_re" | sed -e 's@^%{buildroot}@%dir @') >> bin-man-doc-files
(find %{buildroot}%{perl_vendorlib} -type f | sed -e s@^%{buildroot}@@) > perl-git-files
(find %{buildroot}%{perl_vendorlib} -mindepth 1 -type d | sed -e 's@^%{buildroot}@%dir @') >> perl-git-files

grep Git/SVN perl-git-files > perl-git-svn-files
sed -i "/Git\/SVN/ d" perl-git-files
%if %{with docs}
(find %{buildroot}%{_mandir} -type f | grep -vE "$exclude_re|Git" | sed -e s@^%{buildroot}@@ -e 's/$/*/' ) >> bin-man-doc-files
%else
rm -rf %{buildroot}%{_mandir}
%endif

mkdir -p %{buildroot}%{_localstatedir}/lib/git
install -Dp -m 0644 %{SOURCE6} %{buildroot}%{_unitdir}/git.socket
perl -p \
    -e "s|\@GITEXECDIR\@|%{_libexecdir}/git-core|g;" \
    -e "s|\@BASE_PATH\@|%{_localstatedir}/lib/git|g;" \
    %{SOURCE5} > %{buildroot}%{_unitdir}/git@.service

install -D -m 644 -p contrib/completion/git-completion.bash %{buildroot}%{bashcompdir}/git
ln -s git %{buildroot}%{bashcompdir}/gitk

mkdir -p %{buildroot}%{_datadir}/git-core/contrib/completion
install -m 0644 -p contrib/completion/git-completion.tcsh \
    %{buildroot}%{_datadir}/git-core/contrib/completion/

mkdir -p %{buildroot}%{_datadir}/git-core/contrib
mv contrib/hooks %{buildroot}%{_datadir}/git-core/contrib
pushd contrib > /dev/null
ln -s ../../../git-core/contrib/hooks
popd > /dev/null

mkdir -p %{buildroot}%{_datadir}/git-core/contrib/completion
install -m 0644 -p contrib/completion/git-prompt.sh  %{buildroot}%{_datadir}/git-core/contrib/completion/

desktop-file-install --dir=%{buildroot}%{_datadir}/applications %{SOURCE2}

pushd %{buildroot}%{_libexecdir}/git-core >/dev/null
if cmp -s git-gui git-citool 2>/dev/null; then
    ln -svf git-gui git-citool
fi
popd >/dev/null

%find_lang %{name} %{name}.lang
cat %{name}.lang >> bin-man-doc-files

chmod -R g-w %{buildroot}
chmod a-x %{buildroot}%{_libexecdir}/git-core/git-mergetool--lib

find . -regex '.*/\.\(git\(attributes\|ignore\)\|perlcriticrc\)' -delete
chmod a-x Documentation/technical/api-index.sh
find contrib -type f -print0 | xargs -r0 chmod -x

not_core_re="git-(add--interactive|contacts|credential-netrc|filter-branch|instaweb|request-pull|send-mail)|gitweb"
grep -vE "$not_core_re|%{_mandir}" bin-man-doc-files > bin-files-core
touch man-doc-files-core
%if %{with docs}
grep -vE "$not_core_re" bin-man-doc-files | grep "%{_mandir}" > man-doc-files-core
%endif
grep -E  "$not_core_re" bin-man-doc-files > bin-man-doc-git-files

##### DOC
# place doc files into %%{_pkgdocdir} and split them into expected packages contrib
not_core_doc_re="(git-(cvs|gui|citool|daemon|instaweb|subtree))|p4|svn|email|gitk|gitweb"
mkdir -p %{buildroot}%{_pkgdocdir}/
cp -pr CODE_OF_CONDUCT.md README.md Documentation/*.txt Documentation/RelNotes contrib %{buildroot}%{_pkgdocdir}/

rm -rf %{buildroot}%{_pkgdocdir}/contrib/{contacts,credential}/
cp -p gitweb/INSTALL %{buildroot}%{_pkgdocdir}/INSTALL.gitweb
cp -p gitweb/README %{buildroot}%{_pkgdocdir}/README.gitweb

%if %{with docs}
cp -pr Documentation/*.html Documentation/docbook-xsl.css %{buildroot}%{_pkgdocdir}/
cp -pr Documentation/{howto,technical} %{buildroot}%{_pkgdocdir}/
find %{buildroot}%{_pkgdocdir}/{howto,technical} -type f \
    |grep -o "%{_pkgdocdir}.*$" >> man-doc-files-core
%endif

{
    find %{buildroot}%{_pkgdocdir} -type f -maxdepth 1 \
        | grep -o "%{_pkgdocdir}.*$" \
        | grep -vE "$not_core_doc_re"
    find %{buildroot}%{_pkgdocdir}/{contrib,RelNotes} -type f \
        | grep -o "%{_pkgdocdir}.*$"
    find %{buildroot}%{_pkgdocdir} -type d | grep -o "%{_pkgdocdir}.*$" \
        | sed "s/^/\%dir /"
} >> man-doc-files-core

%check
%if %{without tests}
echo "+++ Skipping tests"
exit 0
%endif

%if %{with docs} && %{with linkcheck}
find %{buildroot}%{_pkgdocdir} -name "*.html" -print0 | xargs -r0 linkchecker
%endif

GIT_SKIP_TESTS="$GIT_SKIP_TESTS \
                t5540.5 t5540.6 t5540.7 t5540.8 t5540.9 t5540.10 t5540.11 \
                t5540.13 t5540.15 t5540.16 t5540.17 t5540.18 t5540.19 t5540.20"

%ifarch aarch64
# Skip tests which fail on aarch64, arm, and ppc
GIT_SKIP_TESTS="$GIT_SKIP_TESTS t5541.37 t5551.25"
%endif



export GIT_SKIP_TESTS
export GIT_TEST_GIT_DAEMON=true
export GIT_TEST_HTTPD=true
export GIT_TEST_SVNSERVE=true
export GIT_TEST_SVN_HTTPD=true
export LANG=en_US.UTF-8


testdir=$(mktemp -d -p /tmp git-t.XXXX)
sed -i "s@^GIT_TEST_OPTS = .*@& --root=$testdir@" config.mak
touch -r GIT-BUILD-OPTIONS ts
sed -i "s@\(GIT_TEST_OPTS='.*\)'@\1 --root=$testdir'@" GIT-BUILD-OPTIONS
touch -r ts GIT-BUILD-OPTIONS

%__make -C t all || ./print-failed-test-output

mkdir -p contrib/credential
mv netrc contrib/credential/
%make_build -C contrib/credential/netrc/ test || \
%make_build -C contrib/credential/netrc/ testverbose

rmdir --ignore-fail-on-non-empty "$testdir"

%post daemon
%systemd_post git.socket

%preun daemon
%systemd_preun git.socket

%postun daemon
%systemd_postun_with_restart git.socket

%files -f bin-man-doc-git-files
%{_datadir}/git-core/templates/hooks/fsmonitor-watchman.sample
%{_datadir}/git-core/templates/hooks/pre-rebase.sample
%{_datadir}/git-core/templates/hooks/prepare-commit-msg.sample
%{_datadir}/git-core/contrib/diff-highlight
%{_datadir}/git-core/contrib/hooks/update-paranoid
%{_datadir}/git-core/contrib/hooks/setgitperms.perl


%files all
# empty files

%files core -f bin-files-core
%{bashcomproot}
%{_datadir}/git-core/
%{!?_licensedir:%global license %doc}
%license COPYING
%exclude %{_datadir}/git-core/templates/hooks/fsmonitor-watchman.sample
%exclude %{_datadir}/git-core/templates/hooks/pre-rebase.sample
%exclude %{_datadir}/git-core/templates/hooks/prepare-commit-msg.sample
%exclude %{_datadir}/git-core/contrib/diff-highlight
%exclude %{_datadir}/git-core/contrib/hooks/update-paranoid
%exclude %{_datadir}/git-core/contrib/hooks/setgitperms.perl


%files core-doc -f man-doc-files-core
%{_pkgdocdir}/contrib/hooks

%if %{with libsecret}
%files credential-libsecret
%{_libexecdir}/git-core/git-credential-libsecret
%endif

%if %{with cvs}
%files cvs
%{_bindir}/git-cvsserver
%{_libexecdir}/git-core/*cvs*
%{_pkgdocdir}/*git-cvs*.txt
%{?with_docs:%{_pkgdocdir}/*git-cvs*.html}
%{?with_docs:%{_mandir}/man1/*cvs*.1*}
%endif

%files daemon
%{_localstatedir}/lib/git
%{_libexecdir}/git-core/git-daemon
%{_unitdir}/git.socket
%{_unitdir}/git@.service
%{_pkgdocdir}/git-daemon*.txt
%{?with_docs:%{_pkgdocdir}/git-daemon*.html}
%{?with_docs:%{_mandir}/man1/git-daemon*.1*}


%files email
%{_libexecdir}/git-core/*email*
%{_pkgdocdir}/*email*.txt
%{?with_docs:%{_pkgdocdir}/*email*.html}
%{?with_docs:%{_mandir}/man1/*email*.1*}


%files -n gitk
%{_bindir}/*gitk*
%{_datadir}/gitk
%{_pkgdocdir}/*gitk*.txt
%{?with_docs:%{_pkgdocdir}/*gitk*.html}
%{?with_docs:%{_mandir}/man1/*gitk*.1*}


%files -n gitweb
%config(noreplace)%{_sysconfdir}/gitweb.conf
%config(noreplace)%{_sysconfdir}/httpd/conf.d/gitweb.conf
%{_pkgdocdir}/*.gitweb
%{_localstatedir}/www/git/
%{_pkgdocdir}/gitweb*.txt
%{?with_docs:%{_pkgdocdir}/gitweb*.html}
%{?with_docs:%{_mandir}/man1/gitweb.1*}
%{?with_docs:%{_mandir}/man5/gitweb.conf.5*}


%files gui
%{_libexecdir}/git-core/git-gui*
%{_libexecdir}/git-core/git-citool
%{_datadir}/git-gui/
%{_datadir}/applications/*git-gui.desktop
%{_pkgdocdir}/git-gui.txt
%{_pkgdocdir}/git-citool.txt
%{?with_docs:%{_mandir}/man1/git-gui.1*}
%{?with_docs:%{_pkgdocdir}/git-gui.html}
%{?with_docs:%{_mandir}/man1/git-citool.1*}
%{?with_docs:%{_pkgdocdir}/git-citool.html}



%files instaweb
%{_libexecdir}/git-core/git-instaweb
%{_pkgdocdir}/git-instaweb.txt
%{?with_docs:%{_pkgdocdir}/git-instaweb.html}
%{?with_docs:%{_mandir}/man1/git-instaweb.1*}


%if %{with p4}
%files p4
%{_libexecdir}/git-core/*p4*
%{_libexecdir}/git-core/mergetools/p4merge
%{_pkgdocdir}/*p4*.txt
%{?with_docs:%{_pkgdocdir}/*p4*.html}
%{?with_docs:%{_mandir}/man1/*p4*.1*}
%endif


%files -n perl-Git-SVN -f perl-git-svn-files
# empty files

%files -n perl-Git -f perl-git-files
%{?with_docs:%{_mandir}/man3/Git.3pm*}

%files subtree
%{_libexecdir}/git-core/git-subtree
%{_pkgdocdir}/git-subtree.txt
%{?with_docs:%{_pkgdocdir}/git-subtree.html}
%{?with_docs:%{_mandir}/man1/git-subtree.1*}


%files svn
%{_libexecdir}/git-core/git-svn
%{_pkgdocdir}/git-svn.txt
%{?with_docs:%{_pkgdocdir}/git-svn.html}
%{?with_docs:%{_mandir}/man1/git-svn.1*}


%changelog
* Wed Apr 26 2023 Funda Wang <fundawang@yeah.net> - 2.40.1-1
- New version 2.40.1

* Wed Apr 12 2023 chen_yu_ao <m15927509890@163.com> - 2.40.0-3
- change spec file format

* Mon Mar 27 2023 mgb01105731 <mgb01105731@alibaba-inc.com> - 2.40.0-2
- Del Specific Fields

* Tue Mar 14 2023 Funda Wang <fundawang@yeah.net> - 2.40.0-1
- New version 2.40.0

* Wed Feb 15 2023 Funda Wang <fundawang@yeah.net> - 2.39.2-1
- New version 2.39.2

* Sat Feb 04 2023 Chunmei Xu <xuchunmei@linux.alibaba.com> - 2.39.1-3
- remove versioned MODULE_COMPAT_ requires

* Mon Jan 30 2023 Chunmei Xu <xuchunmei@linux.alibaba.com> - 2.39.1-2
- rebuild with perl 5.36.0

* Wed Jan 18 2023 Funda Wang <fundawang@yeah.net> - 2.39.1-1
- New version 2.39.1

* Sat Dec 17 2022 Funda Wang <fundawang@yeah.net> - 2.39.0-1
- New version 2.39.0

* Sun Dec 11 2022 Funda Wang <fundawang@yeah.net> - 2.38.2-1
- New version 2.38.1

* Sun Nov 13 2022 Funda Wang <fundawang@yeah.net> - 2.38.1-1
- New version 2.38.1

* Wed Sep 07 2022 happy_orange <songnannan@linux.alibaba.com> - 2.37.3-1
- update to 2.37.3

* Fri Jun 10 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 2.36.1-2
- remove dependency of apr-util-bdb and add skip testcases

* Tue May 17 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 2.36.1-1
- Init from upstream version 2.36.1
